<div class="msg msg-error">
    <div class="msg-body">
        <i class="icon icon-alert-circle"></i>
        <div class="msg-text"><%- msg %></div>
        <button type="button" class="close">
            <span aria-hidden="true">×</span>
            <span class="sr-only">Close</span>
        </button>
    </div>
</div>
