<div class="section-header <%- isExpandable %>">
    <% if (label) { %>
    <p class="section-label">
        <% if (isExpandable) { %><i class="icon-chevron-right"></i><% } %>
        <%- label %>
    </p><% } %>
</div>
<div class="section-body">
</div>
