.tab-content {
    overflow: visible !important;
}

/*Navigation tab shadow*/
.nav-tabs > li > a:focus {
    box-shadow: none;
}

.main-section-body .nav-tabs > .active {
    border-bottom: none;
}

a:focus {
    box-shadow: none;
}

/*Leave space for error message display*/
.nav-tabs {
    height: auto;
    margin-bottom: 0px;
}

/*Prevent scroll in form*/
.tab-content .modal-body {
    height: auto;
    max-height: none;
}
