export const ERROR_REQUEST_TIMEOUT_TRY_AGAIN = 'Request time out while authenticating. Please try again.';
export const ERROR_REQUEST_TIMEOUT_ACCESS_TOKEN_TRY_AGAIN = 'Request time out while getting accesstoken. Please try again.';
export const ERROR_OCCURRED_TRY_AGAIN = "Error occurred while trying to authenticate. Please try Again.";
export const ERROR_AUTH_PROCESS_TERMINATED_TRY_AGAIN = "Authentication process interrupted. Please try again.";
export const ERROR_STATE_MISSING_TRY_AGAIN = "Response not received from the expected sender. Please try again.";